#!/usr/bin/python

################################################################################
##3456789 123456789 123456789 123456789 123456789 123456789 123456789 123456789
##      10        20        30        40        50        60        70        80
##
## Info: 
##    Example of how to use libnotify correctly
##
## Run:
##    chmod +x update-notifications.py
##    ./update-notifications.py
##
## Copyright 2013 Canonical Ltd.
##
## Author:
##    Mirco "MacSlow" Mueller <mirco.mueller@canonical.com>
##
## This program is free software: you can redistribute it and/or modify it
## under the terms of the GNU General Public License version 3, as published
## by the Free Software Foundation.
##
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranties of
## MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
## PURPOSE.  See the GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License along
## with this program.  If not, see <http://www.gnu.org/licenses/>.
##
################################################################################

import os
import sys
import time
import pynotify
import example

if __name__ == '__main__':
	if not pynotify.init ("update-notifications"):
		sys.exit (1)

	# call this so we can savely use capabilities dictionary later
	example.initCaps ()

	# show what's supported
	example.printCaps ()

	# try the icon-summary-body case
	n = pynotify.Notification (
			"Inital notification (1. notification)",
			"This is the original content of this notification-bubble.",
			os.getcwd() + "/assets/avatar1.jpg")
	n.show ()
	time.sleep (2); # simulate app activity

	# update the current notification with new content
	n.update ("Updated notification (1. notification)",
		  "Here the same bubble with new title- and body-text, even the icon can be changed on the update.",
                  os.getcwd() + "/assets/avatar2.jpg")
	n.show ();
	time.sleep (4); # wait longer now

	# create a new bubble using the icon-summary-body layout
	n = pynotify.Notification (
			"Initial layout (2. notification)",
			"This bubble uses the icon-title-body layout with a secondary icon.",
			os.getcwd() + "/assets/avatar3.jpg")
        n.set_hint_string ("x-canonical-secondary-icon", "message");
	n.show ()
	time.sleep (2); # simulate app activity

	# now update current bubble again, but change the layout
	n.clear_hints()
	n.update ("Updated layout (2. notification)",
		  "After the update we now have a bubble using the title-body layout.",
		  " ")
	n.show ()



#!/usr/bin/python

################################################################################
##3456789 123456789 123456789 123456789 123456789 123456789 123456789 123456789
##      10        20        30        40        50        60        70        80
##
## Info: 
##    Example of how to use libnotify correctly
##
## Run:
##    chmod +x sd-example-event-reminder.py
##    ./sd-example-event-reminder.py
##
## Copyright 2014 Canonical Ltd.
##
## Author:
##    Mirco "MacSlow" Mueller <mirco.mueller@canonical.com>
##
## This program is free software: you can redistribute it and/or modify it
## under the terms of the GNU General Public License version 3, as published
## by the Free Software Foundation.
##
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranties of
## MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
## PURPOSE.  See the GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License along
## with this program.  If not, see <http://www.gnu.org/licenses/>.
##
################################################################################

import os
import sys
import time
import pynotify
import gobject
import example

def action_view (notification, action):
	if action == "view":
		print "Viewing the thing."
	else:
		print "That should not have happened (action_view)!"

def action_snooze (notification, action):
	if action == "snooze":
		print "You want to snooze some more you lazy bastard!"
	else:
		print "That should not have happened (action_snooze)!"

def action_ok (notification, action):
	if action == "ok":
		print "Getting up is the right thing to do... good for you!"
	else:
		print "That should not have happened (action_ok)!"

def pushNotification (title, body, icon):
	n = pynotify.Notification (title, body, icon);

	# NOTE: the order in which actions are added is important... positive
	# always comes first!
	n.add_action ("ok", "Ok", action_ok);
	n.add_action ("snooze", "Snooze", action_snooze);
	n.add_action ("view", "View", action_view);

	# indicate to the notification-daemon, that we want to use snap-decisions
	n.set_hint_string ("x-canonical-snap-decisions", "true");
	n.set_hint_string ("x-canonical-non-shaped-icon", "true");
	n.set_hint_string ("x-canonical-private-affirmative-tint", "true");

	n.show ()
	return n

if __name__ == '__main__':
	if not pynotify.init ("sd-example-event-reminder"):
		sys.exit (1)

	# call this so we can savely use capabilities dictionary later
	example.initCaps ()

	# show what's supported
	example.printCaps ()

	# be nice and check for required capabilities
	if not example.capabilities['x-canonical-snap-decisions'] \
		and example.capabilities['x-canonical-non-shaped-icon'] \
		and example.capabilities['x-canonical-private-affirmative-tint']:
		sys.exit (2)

	loop = gobject.MainLoop ()
	n = pushNotification ("Theatre at Ferria Stadium", "at Ferria Stadium in Bilbao, Spain\n07578545317", "")
	n.connect ("closed", example.closedHandler, loop)
	loop.run ()



#!/usr/bin/python

################################################################################
##3456789 123456789 123456789 123456789 123456789 123456789 123456789 123456789
##      10        20        30        40        50        60        70        80
##
## Info: 
##    Example of how to use libnotify correctly and at the same time comply to
##    the new jaunty notification spec (read: visual guidelines)
##
## Run:
##    chmod +x example.py
##    ./example.py
##
## Copyright 2012 Canonical Ltd.
##
## Author:
##    Mirco "MacSlow" Mueller <mirco.mueller@canonical.com>
##
## This program is free software: you can redistribute it and/or modify it
## under the terms of the GNU General Public License version 3, as published
## by the Free Software Foundation.
##
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranties of
## MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
## PURPOSE.  See the GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License along
## with this program.  If not, see <http://www.gnu.org/licenses/>.
##
################################################################################

import pynotify

# even in Python this is globally nasty :), do something nicer in your own code
capabilities = {'actions':                              False,
		'body':                                 False,
		'body-hyperlinks':                      False,
		'body-images':                          False,
		'body-markup':                          False,
		'icon-multi':                           False,
		'icon-static':                          False,
		'sound':                                False,
		'sound-file':                           False,
		'suppress-sound':                       False,
		'image/svg+xml':                        False,
		'urgency':                              False,
		'value':                                False,
		'x-canonical-value-bar-tint':           False,
		'x-canonical-private-synchronous':      False,
		'x-canonical-private-icon-only':        False,
		'x-canonical-truncation':               False,
		'x-canonical-snap-decisions':           False,
		'x-canonical-snap-decisions-timeout':   False,
		'x-canonical-snap-decisions-swipe':     False,
		'x-canonical-switch-to-application':    False,
		'x-canonical-secondary-icon':           False,
		'x-canonical-private-affirmative-tint': False,
		'x-canonical-private-rejection-tint':   False,
		'x-canonical-private-menu-model':       False,
		'x-canonical-non-shaped-icon':          False}

def initCaps ():
	caps = pynotify.get_server_caps ()
	if caps is None:
	        print "Failed to receive server caps."
		sys.exit (1)

	for cap in caps:
		capabilities[cap] = True

def printCaps ():
	info = pynotify.get_server_info ()
	print "Name:          " + info["name"]
	print "Vendor:        " + info["vendor"]
	print "Version:       " + info["version"]
	print "Spec. Version: " + info["spec-version"]

	caps = pynotify.get_server_caps ()
	if caps is None:
	        print "Failed to receive server caps."
		sys.exit (1)

	print "Supported capabilities/hints:"
	if capabilities['actions']:
		print "\tactions"
	if capabilities['body']:
		print "\tbody"
	if capabilities['body-hyperlinks']:
		print "\tbody-hyperlinks"
	if capabilities['body-images']:
		print "\tbody-images"
	if capabilities['body-markup']:
		print "\tbody-markup"
	if capabilities['icon-multi']:
		print "\ticon-multi"
	if capabilities['icon-static']:
		print "\ticon-static"
	if capabilities['sound']:
		print "\tsound"
	if capabilities['sound-file']:
		print "\tsound-file"
	if capabilities['suppress-sound']:
		print "\tsuppress-sound"
	if capabilities['urgency']:
		print "\turgency"
	if capabilities['value']:
		print "\tvalue"
	if capabilities['x-canonical-value-bar-tint']:
		print "\tx-canonical-value-bar-tint"
	if capabilities['image/svg+xml']:
		print "\timage/svg+xml"
	if capabilities['x-canonical-private-synchronous']:
		print "\tx-canonical-private-synchronous"
	if capabilities['x-canonical-private-icon-only']:
		print "\tx-canonical-private-icon-only"
	if capabilities['x-canonical-truncation']:
		print "\tx-canonical-truncation"
	if capabilities['x-canonical-snap-decisions']:
		print "\tx-canonical-snap-decisions"
	if capabilities['x-canonical-snap-decisions-timeout']:
		print "\tx-canonical-snap-decisions-timeout"
	if capabilities['x-canonical-snap-decisions-swipe']:
		print "\tx-canonical-snap-decisions-swipe"
	if capabilities['x-canonical-switch-to-application']:
		print "\tx-canonical-switch-to-application"
	if capabilities['x-canonical-secondary-icon']:
		print "\tx-canonical-secondary-icon"
	if capabilities['x-canonical-private-affirmative-tint']:
		print "\tx-canonical-private-affirmative-tint"
	if capabilities['x-canonical-private-rejection-tint']:
		print "\tx-canonical-private-rejection-tint"
	if capabilities['x-canonical-private-menu-model']:
		print "\tx-canonical-private-menu-model"
	if capabilities['x-canonical-non-shaped-icon']:
		print "\tx-canonical-non-shaped-icon"

	print "Notes:"
	if info["name"] == "notify-osd":
		print "\tx- and y-coordinates hints are ignored"
		print "\texpire-timeout is ignored"
		print "\tbody-markup is accepted but filtered"
	else:
		print "\tnone"

def closedHandler (notification, loop):
	print "\"closed\"-handler called"
	loop.quit ()



#!/usr/bin/python

################################################################################
##3456789 123456789 123456789 123456789 123456789 123456789 123456789 123456789
##      10        20        30        40        50        60        70        80
##
## Info: 
##    Example of how to use libnotify correctly
##
## Run:
##    chmod +x icon-value.py
##    ./icon-value.py
##
## Copyright 2013 Canonical Ltd.
##
## Author:
##    Mirco "MacSlow" Mueller <mirco.mueller@canonical.com>
##
## This program is free software: you can redistribute it and/or modify it
## under the terms of the GNU General Public License version 3, as published
## by the Free Software Foundation.
##
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranties of
## MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
## PURPOSE.  See the GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License along
## with this program.  If not, see <http://www.gnu.org/licenses/>.
##
################################################################################

import sys
import time
import pynotify
import example

def pushNotification (icon, value):
	n = pynotify.Notification ("Brightness", # for a11y-reasons supply something meaning full
				   "",           # this needs to be empty!
				   icon);
	n.set_hint_int32 ("value", value);
	n.set_hint_string ("x-canonical-private-synchronous", "true");
	n.show ()
	time.sleep (1)

if __name__ == '__main__':
	if not pynotify.init ("icon-value"):
		sys.exit (1)

	# call this so we can savely use capabilities dictionary later
	example.initCaps ()

	# show what's supported
	example.printCaps ()

	# try the icon-value case
	if example.capabilities['x-canonical-private-icon-only']:
		pushNotification ("notification-keyboard-brightness-low", 25);

		pushNotification ("notification-keyboard-brightness-medium", 50);

		pushNotification ("notification-keyboard-brightness-high", 75);

		pushNotification ("notification-keyboard-brightness-full", 100);

		# trigger "overshoot"-effect
		pushNotification ("notification-keyboard-brightness-full", 101);

		pushNotification ("notification-keyboard-brightness-high", 75);

		pushNotification ("notification-keyboard-brightness-medium", 50);

		pushNotification ("notification-keyboard-brightness-low", 25);

		pushNotification ("notification-keyboard-brightness-off", 0);

		# trigger "undershoot"-effect
		pushNotification ("notification-keyboard-brightness-off", -1);
	else:
		print "The daemon does not support the x-canonical-private-icon-only hint!"




#!/usr/bin/python

################################################################################
##3456789 123456789 123456789 123456789 123456789 123456789 123456789 123456789
##      10        20        30        40        50        60        70        80
##
## Info: 
##    Example of how to use libnotify correctly and at the same time comply to
##    the new jaunty notification spec (read: visual guidelines)
##
## Run:
##    chmod +x sd-example-much-body-text.py
##    ./sd-example-much-body-text.py
##
## Copyright 2012 Canonical Ltd.
##
## Author:
##    Mirco "MacSlow" Mueller <mirco.mueller@canonical.com>
##
## This program is free software: you can redistribute it and/or modify it
## under the terms of the GNU General Public License version 3, as published
## by the Free Software Foundation.
##
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranties of
## MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
## PURPOSE.  See the GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License along
## with this program.  If not, see <http://www.gnu.org/licenses/>.
##
################################################################################

import sys
import time
import pynotify
import gobject
import example

def action_decline (notification, action):
	if action == "decline_id":
		print "Declined"
	else:
		print "That should not have happened (action_decline)!"

def action_ok (notification, action):
	if action == "ok_id":
		print "Ok"
	else:
		print "That should not have happened (action_ok)!"

def pushNotification (title, body, icon):
	n = pynotify.Notification (title, body, icon);

	# NOTE: the order in which actions are added is important... positive
	# always comes first!
	n.add_action ("ok_id",      "Ok",     action_ok);
	n.add_action ("decline_id", "Cancel", action_decline);

	# indicate to the notification-daemon, that we want to use snap-decisions
	n.set_hint_string ("x-canonical-snap-decisions", "true");

	# set the button-tint hint so that the right/positive button is tinted and
	# not using the stock clear-color
	n.set_hint_string ("x-canonical-private-affirmative-tint", "true");
	n.set_hint_string ("x-canonical-private-rejection-tint", "true");
	n.set_hint_string ("x-canonical-non-shaped-icon", "true");

	n.show ()
	return n

if __name__ == '__main__':
	if not pynotify.init ("sd-example-much-body-text"):
		sys.exit (1)

	# call this so we can savely use capabilities dictionary later
	example.initCaps ()

	# show what's supported
	example.printCaps ()

	# be nice and check for required capabilities
	if not example.capabilities['x-canonical-private-affirmative-tint'] \
		and not example.capabilities['x-canonical-private-rejection-tint'] \
		and not example.capabilities['x-canonical-snap-decisions']:
		sys.exit (2)

	loop = gobject.MainLoop ()
	n = pushNotification ("Uses much text",
		"Lorem ipsum dolor sit amet,"
		" consetetur sadipscing elitr,"
		" sed diam nonumy eirmod tempor"
		" invidunt ut labore et dolore"
		" magna aliquyam erat, sed diam"
		" voluptua. At vero eos et accusam"
		" et justo duo dolores et ea rebum."
		" Stet clita kasd gubergren, no sea"
		" takimata sanctus est Lorem ipsum"
		" dolor sit amet.",
		"message")
	n.connect ("closed", example.closedHandler, loop)
	loop.run ()
